#
# spec file for package lxqt-policykit
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lxqt-policykit
Version:        1.4.0
Release:        bp156.1.1
Summary:        PolicyKit authentication agent
License:        LGPL-2.1-or-later
Group:          System/GUI/LXQt
URL:            http://www.lxqt.org
Source:         https://github.com/lxqt/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:        https://github.com/lxqt/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  cmake >= 3.1.0
BuildRequires:  gcc-c++
BuildRequires:  lxqt-build-tools-devel >= 0.11.0
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  pkgconfig(Qt5UiTools) >= 5.15.0
BuildRequires:  pkgconfig(Qt5Xdg)
BuildRequires:  pkgconfig(lxqt) >= %{version}
BuildRequires:  pkgconfig(lxqt-globalkeys) >= %{version}
BuildRequires:  pkgconfig(polkit-agent-1)
BuildRequires:  pkgconfig(polkit-qt5-core-1)
Recommends:     %{name}-lang

%description
PolicyKit authentication agent for LXQt

%lang_package

%prep
%setup -q

%build
%cmake -DPULL_TRANSLATIONS=No

%install
%cmake_install
install -Dm 0644 man/%{name}-agent.1 %{buildroot}%{_mandir}/man1/%{name}-agent.1

%find_lang lxqt-policykit-agent --with-qt

%files
%license LICENSE
%doc AUTHORS
%{_bindir}/lxqt-policykit-agent
%{_mandir}/man?/%{name}-agent.?%{ext_man}
%config %{_sysconfdir}/xdg/autostart/lxqt-policykit-agent.desktop

%files lang -f lxqt-policykit-agent.lang

%dir %{_datadir}/lxqt
%dir %{_datadir}/lxqt/translations
%{_datadir}/lxqt/translations/lxqt-policykit-agent

%changelog
* Sun Nov  5 2023 Shawn Dunn <sfalken@opensuse.org>
- Update to 1.4.0:
  * Prevent multiple instances of authentication-in-progress dialog
  * Prevent waiting indefinitely for the authentication by
    notifying polkit that we couldn't do the next authentication
    if one is already in progress.
* Sat Nov  5 2022 Shawn Dunn <sfalken@cloverleaf-linux.org>
- Update to 1.2.0:
  * Updated translations and bumped the version.
* Fri Apr 29 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.1.0:
  * Updated translations and bumped the version.
* Mon Nov  8 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.0.0:
  * Bumped minimum required Qt version and updated translations.
* Fri Apr 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.17.0:
  * A better memory handling.
  * Code cleanup.
* Wed Nov  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.16.0:
  * Bumped version to 0.16.0.
  * Translation updates.
* Mon Apr 27 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Changed lxqt-policykit.keyring to tsujan's key
* Sat Apr 25 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 0.15.0
  * Prevented showing password.
  * Made the infobox non-modal.
* Fri Mar  1 2019 mvetter@suse.com
- Update to 0.14.1:
  * Only translations was changed
* Thu Jan 31 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.14.0:
  * Installed former missed man page
- Move translation from lxqt-l10n into package
* Tue May 22 2018 mvetter@suse.com
- Update to 0.13.0:
  * CMake: Prevent in-source builds
  * fix razor-qt -> lxqt and http -> https
  * Fixed some LXDE mentions
  * Drop Qt foreach
* Mon Oct 23 2017 mvetter@suse.com
- Update to 0.12.0:
  * Set patch version
  * Don't export github templates
  * Updated Lithuanian translation
  * Drops Qt5Core_VERSION_STRING
  * Added QCommandLineParser and basic cli interface to lxqt-policykit-agent
  * Added default CMAKE_BUILD_TYPE and LXQT_POLKITAGENT_PATCH_VERSION
  * Fixes a FTBFS in superbuild mode
  * Added merged autostart to CMakeLists.txt
  * Updated *_da.desktop files and removed *_da_DK.desktop files
  * Update desktop entries and Replace fr_FR by fr
  * Update Greek translation (el) Remove country variant from language code
  * CMake: Adds Runtime and Devel install COMPONENTs
  * Coding style changes
  * Updates the build system to use the Targets infrastructure
  * Drops hardcoded /etc/xdg paths
  * Updated german translation, replaced Qt4 by Qt in all xsession/translations
  * Updates translations infrastructure
  * Update the required minimum cmake version
  * remove dead template lines switch OnlyShowIn from Razor -> LXQt stringchanges LxQt -> LXQt
  * Support lxqt-session and add necessary xdg autostart desktop entry files.
  * Fix typo and correct some sentences
  * Fixed some more typos
  * Bump year
* Fri Feb 24 2017 sfalken@opensuse.org
- Update to 0.11.1:
  * Make CMakeLists.txt more uniform.
  * Remove cpack (#25)
* Sat Sep 24 2016 mvetter@suse.com
- Update to 0.11.0:
  * agentGui: Use default icon
  * agentGui: Choose current user in identities combo
  * agentGui: Handle setting the prompt correctly
  * agent: Handle multiple identities correctly
  * Update README.md
  * Fixed typo prefered -> preferred
  * Add README.md
  * build: Use external translations
  * ts-files removal (#21)
  * Bump year in AUTHORS
  * Italian translation update
  * Updated Russian translation Removed ru_RU file
  * update: lxqt-policykit-agent_hu.ts
- Add keyring
* Fri Nov  6 2015 mvetter@suse.com
- Upstream release 0.10.0
* Fri Feb 20 2015 sfalken@opensuse.org
- Changed %%build and %%install to use cmake macros
* Mon Feb  9 2015 sfalken@opensuse.org
- New upstream version 0.9.0
- Added -lang subpackage
* Mon Jan 26 2015 sfalken@opensuse.org
- Added conditionals to enable Fedora builds
* Mon Nov 10 2014 andrea@opensuse.org
- Fixed License string
* Sat Oct 25 2014 andrea@opensuse.org
- new upstream version 0.8.0
* Tue May 13 2014 andrea@opensuse.org
- removed unsed buildrequires
* Tue May 13 2014 sfalken@opensuse.org
- Specfile cleanup
* Mon May 12 2014 sfalken@opensuse.org
- removed fedora spec, split into subproject
  Del:  lxqt-policykit-Fedora_20.spec
* Sat May 10 2014 sfalken@opensuse.org
- Ran spec-cleaner on openSUSE specfile
* Fri May  9 2014 sfalken@opensuse.org
- Added specfile for Fedora_20
  Add: lxqt-policykit-Fedora_20.spec
* Fri May  9 2014 sfalken@opensuse.org
- Added tarball for new stable release
  Add:  lxqt-policykit-0.7.0.tar.xz
  Del:  _service
* Thu Apr  3 2014 sfalken@opensuse.org
- Initial Source Upload
  Add: _service
  Add: lxqt-policykit.spec
  Add: lxqt-policykit.changes
